SystemOrganization addCategory: #ConfigurationOfKendrick!

Object subclass: #ConfigurationOfKendrick
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfKendrick'!

!ConfigurationOfKendrick commentStamp: 'SergeStinckwich 7/21/2014 14:58' prior: 0!
ConfigurationOfKendrick is a Metacello Configuration to load the packages of the Kendrick project.

Kendrick is a Domain-Specific Language and Simulation Plaform for mathematical epidemiology modeling. All the development happens on SmalltalkHub at the moment: http://bit.ly/XrpsL2

Kendrick is based extensively on several tools of the meta-modeling platform MOOSE including PetitParser and Graph-ET.

Github is only used to to store the issues list: https://github.com/UMMISCO/Kendrick/issues?state=open!

!ConfigurationOfKendrick class methodsFor: 'development support' stamp: 'SergeStinckwich 3/14/2014 15:43'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfKendrick class methodsFor: 'private' stamp: 'SergeStinckwich 3/14/2014 15:43'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfKendrick class methodsFor: 'private' stamp: 'SergeStinckwich 3/14/2014 15:43'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfKendrick class methodsFor: 'private' stamp: 'SergeStinckwich 3/14/2014 15:43'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfKendrick class methodsFor: 'metacello tool support' stamp: 'SergeStinckwich 3/14/2014 15:43'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfKendrick class methodsFor: 'loading' stamp: 'SergeStinckwich 3/14/2014 15:43'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfKendrick class methodsFor: 'loading' stamp: 'SergeStinckwich 3/14/2014 15:43'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfKendrick class methodsFor: 'loading' stamp: 'SergeStinckwich 3/14/2014 15:43'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfKendrick class methodsFor: 'accessing' stamp: 'SergeStinckwich 3/14/2014 15:43'!
project

	^self new project! !

!ConfigurationOfKendrick class methodsFor: 'development support' stamp: 'SergeStinckwich 3/14/2014 15:43'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 3/17/2014 19:39'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec 
			project: 'Fame' with: [
				spec
					className: #ConfigurationOfFame;
					versionString: 'bleedingEdge';
					repository: 'http://smalltalkhub.com/mc/Moose/Fame/main/' ];
			project: 'GraphET' with: [
				spec
					className: #ConfigurationOfGraphET;
					versionString: 'stable';
					repository: 'http://smalltalkhub.com/mc/ObjectProfile/GraphET/main/' ].
		spec package: 'Kendrick'. ].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 4/15/2014 15:06'!
baseline02: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ].
		spec package: 'Kendrick'. ].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 4/16/2014 16:22'!
baseline03: spec
	<version: '0.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ].
		spec project: 'SciSmalltalk' with: [
				spec
					className: #ConfigurationOfSciSmalltalk;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main/' ].
		spec 
			package: 'Kendrick'].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 3/23/2015 16:38'!
baseline04: spec
	<version: '0.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ].
		spec project: 'SciSmalltalk' with: [
				spec
					className: #ConfigurationOfSciSmalltalk;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main/' ].
		spec project: 'Ston' with: [ 
					spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository:'http://ss3.gemstone.com/ss/STON'].
		spec 
			package: 'Kendrick'].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 4/28/2015 22:04'!
baseline05: spec
	<version: '0.5-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec 
			project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ];
			project: 'SciSmalltalk' with: [
				spec
					className: #ConfigurationOfSciSmalltalk;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main/' ];
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://ss3.gemstone.com/ss/STON' ].
		spec 
			package: 'Kendrick';
			package: 'Glamour-Magritte-Presentations'. ].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 4/28/2015 22:55'!
baseline06: spec
	<version: '0.6-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec 
			project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ];
			project: 'SciSmalltalk' with: [
				spec
					className: #ConfigurationOfSciSmalltalk;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main/' ];
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Glamour' with: [
				spec
					className: #ConfigurationOfGlamour;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Moose/Glamour/main/' ].
		spec 
			package: 'Kendrick';
			package: 'Glamour-Magritte-Presentations' with: [
				spec requires: #('Glamour' ). ]. ].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'AlvaroJosePeraltaOcampo 4/29/2015 16:31'!
baseline07: spec
	<version: '0.7-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec 
			project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ];
			project: 'SciSmalltalk' with: [
				spec
					className: #ConfigurationOfSciSmalltalk;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main/' ];
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Glamour' with: [
				spec
					className: #ConfigurationOfGlamour;
					versionString: #'stable';
					loads: #('Glamour-Magritte-Presentations' );
					repository: 'http://smalltalkhub.com/mc/Moose/Glamour/main/' ].
		spec package: 'Kendrick'. ].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 6/16/2015 14:22'!
baseline08: spec
	<version: '0.8-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec 
			project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ];
			project: 'SciSmalltalk' with: [
				spec
					className: #ConfigurationOfSciSmalltalk;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main/' ];
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Glamour' with: [
				spec
					className: #ConfigurationOfGlamour;
					versionString: #'stable';
					loads: #('Glamour-Magritte-Presentations' );
					repository: 'http://smalltalkhub.com/mc/Moose/Glamour/main/' ];
			project: 'VirtualGPU' with: [
				spec
					className:#ConfigurationOfVirtualGPU;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/ronsaldo/VirtualGPU/main'].
		spec package: 'Kendrick'. ].
! !

!ConfigurationOfKendrick methodsFor: 'baselines' stamp: 'SergeStinckwich 6/16/2015 14:23'!
baseline09: spec
	<version: '0.9-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/UMMISCO/Kendrick/main/'.
		spec 
			project: 'Moose' with: [
				spec
					className: #ConfigurationOfMoose;
					versionString: #'stable';
					repository: 'http://smalltalkhub.com/mc/Moose/Moose/main/' ];
			project: 'SciSmalltalk' with: [
				spec
					className: #ConfigurationOfSciSmalltalk;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main/' ];
			project: 'Ston' with: [
				spec
					className: #ConfigurationOfSton;
					versionString: #'stable';
					repository: 'http://ss3.gemstone.com/ss/STON' ];
			project: 'Glamour' with: [
				spec
					className: #ConfigurationOfGlamour;
					versionString: #'stable';
					loads: #('Glamour-Magritte-Presentations' );
					repository: 'http://smalltalkhub.com/mc/Moose/Glamour/main/' ];
			project: 'VirtualGPU' with: [
				spec
					className:#ConfigurationOfVirtualGPU;
					versionString: #'development';
					repository: 'http://smalltalkhub.com/mc/ronsaldo/VirtualGPU/main'].
		spec package: 'Kendrick'. ].
! !

!ConfigurationOfKendrick methodsFor: 'catalog' stamp: 'SergeStinckwich 4/28/2015 22:57'!
catalogChangeLog
	"Returns a paragraph describing the most important changes in the configuration class."
	^ '- Version number - Date - topics
[[[
	ConfigurationOfXXX project version: ''xx'' ) load					
]]]
or simply
- Version number - Date - topics
- Version number - Date - topics
- Version number - Date - topics.'! !

!ConfigurationOfKendrick methodsFor: 'catalog' stamp: 'SergeStinckwich 4/28/2015 22:58'!
catalogContactInfo
	"Returns a paragraph describing contact information such as email, mailing lists and website."
	^ 'You will more information about the Kendrick project on this website: http://ummisco.github.io/kendrick/'! !

!ConfigurationOfKendrick methodsFor: 'catalog' stamp: 'SergeStinckwich 4/28/2015 22:59'!
catalogDescription
	"Returns a paragraph describing the project"
	^ 'Kendrick is a Domain-Specific Language and Simulation Plaform for mathematical epidemiology modeling.
Kendrick is based extensively on several tools of the meta-modeling platform MOOSE including PetitParser and ROASSAL visualisation engine.'! !

!ConfigurationOfKendrick methodsFor: 'catalog' stamp: 'SergeStinckwich 4/28/2015 22:57'!
catalogKeyClassesAndExample
	"Returns a paragraph or more describing the key classes of your project. You can use Pillar/Pier syntax to layout out the text i.e., ==Code== and - for bullet."
	^ 'MyProject is composed of one cool key class named ==MyProject==. There is also ==MyKeyHelper==
- ==MyProject== is the responsible for many cool aspects.
- ==MyKeyHelper== is helping ==MyProject=='! !

!ConfigurationOfKendrick methodsFor: 'catalog' stamp: 'SergeStinckwich 4/28/2015 22:57'!
catalogKeywords
	"Returns an array of symbols"
	^ #(epidemiology science) ! !

!ConfigurationOfKendrick methodsFor: 'accessing' stamp: 'SergeStinckwich 3/14/2014 15:43'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfKendrick methodsFor: 'symbolic versions' stamp: 'SergeStinckwich 6/23/2015 11:59'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.9-baseline'.
! !

!ConfigurationOfKendrick methodsFor: 'accessing' stamp: 'SergeStinckwich 3/14/2014 15:43'!
project

	^ project ifNil: [ 
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfKendrick methodsFor: 'symbolic versions' stamp: 'SergeStinckwich 11/4/2015 16:55'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.24'.
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 9/22/2014 14:38'!
version010: spec
	<version: '0.10' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.10 - All green tests'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '9/22/2014 12:30'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.14'.
		spec package: 'Kendrick' with: 'Kendrick-BUIThiMaiAnh.272']
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 9/30/2014 16:41'!
version011: spec
	<version: '0.11' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.11'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '9/30/2014 16:40'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.14'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.282']
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 10/9/2014 15:08'!
version012: spec
	<version: '0.12' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.12'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '10/09/2014 15:07'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.14'.
		spec package: 'Kendrick' with: 'Kendrick-BUIThiMaiAnh.287']
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 10/17/2014 11:35'!
version013: spec
	<version: '0.13' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.13'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '10/16/2014 11:35'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.14'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.306']
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/22/2015 17:20'!
version014: spec
	<version: '0.14' imports: #('0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.14'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '2014-11-24T18:21:19.244195+01:00'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.16-baseline';
			project: 'Ston' with: '0.10'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.307']
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 3/23/2015 16:34'!
version015: spec
	<version: '0.15' imports: #('0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.15'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '3/23/2015 16:34'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.16-baseline';
			project: 'Ston' with: '0.10'.
		spec package: 'Kendrick' with: 'Kendrick-BuiThiMaiAnh.363'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/22/2015 17:16'!
version016: spec
	<version: '0.16' imports: #('0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.16'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/22/2015 17:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.16-baseline';
			project: 'Ston' with: '0.12'.
		spec package: 'Kendrick' with: 'Kendrick-BuiThiMaiAnh.364'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/28/2015 22:05'!
version017: spec
	<version: '0.17' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.17'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/28/2015 22:05'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.16-baseline';
			project: 'Ston' with: '0.12'.
		spec 
			package: 'Kendrick' with: 'Kendrick-AlvaroJosePeraltaOcampo.366';
			package: 'Glamour-Magritte-Presentations' with: 'Glamour-Magritte-Presentations-AndreiChis.7'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'AlvaroJosePeraltaOcampo 4/29/2015 16:31'!
version018: spec
	<version: '0.18' imports: #('0.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.18'.
		spec author: 'AlvaroJosePeraltaOcampo'.
		spec timestamp: '4/29/2015 16:31'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.16-baseline';
			project: 'Ston' with: '0.12';
			project: 'Glamour' with: '3.0.8'.
		spec package: 'Kendrick' with: 'Kendrick'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 5/21/2015 10:36'!
version019: spec
	<version: '0.19' imports: #('0.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.19'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '5/08/2015 18:09'.
		spec 
			project: 'Moose' with: '5.1-baseline';
			project: 'SciSmalltalk' with: '0.17-baseline';
			project: 'Ston' with: '0.12';
			project: 'Glamour' with: '3.3.0'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.373'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 5/27/2015 10:24'!
version020: spec
	<version: '0.20' imports: #('0.7-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.20'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '5/27/2015 10:22'.
		spec 
			project: 'Moose' with: '5.1-baseline';
			project: 'SciSmalltalk' with: '0.18-baseline';
			project: 'Ston' with: '0.12';
			project: 'Glamour' with: '3.3.0'.
		spec package: 'Kendrick' with: 'Kendrick-BuiThiMaiAnh.377'. ]
! !

!ConfigurationOfKendrick methodsFor: 'as yet unclassified' stamp: 'SergeStinckwich 6/1/2015 10:22'!
version021: spec
	<version: '0.21' imports: #('0.8-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.21'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '6/1/2015 10:05'.
		spec 
			project: 'Moose' with: '5.1-baseline';
			project: 'SciSmalltalk' with: '0.18-baseline';
			project: 'Ston' with: '0.12';
			project: 'Glamour' with: '3.3.0';
			project: 'VirtualGPU' with:'0.1-baseline'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.383'. ]
! !

!ConfigurationOfKendrick methodsFor: 'as yet unclassified' stamp: 'SergeStinckwich 6/16/2015 14:30'!
version022: spec
	<version: '0.22' imports: #('0.9-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.22'.
		spec author: 'cheikhou'.
		spec timestamp: '6/16/2015 11:16'.
		spec 
			project: 'Moose' with: '5.1';
			project: 'SciSmalltalk' with: '0.18-baseline';
			project: 'Ston' with: '0.12';
			project: 'Glamour' with: '3.3.0';
			project: 'VirtualGPU' with:'0.1-baseline'.
		spec package: 'Kendrick' with: 'Kendrick-cheikhouka.398'. ]
! !

!ConfigurationOfKendrick methodsFor: 'as yet unclassified' stamp: 'SergeStinckwich 6/23/2015 11:56'!
version023: spec
	<version: '0.23' imports: #('0.9-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.23'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '6/23/2015 11:54'.
		spec 
			project: 'Moose' with: '5.1';
			project: 'SciSmalltalk' with: '0.18-baseline';
			project: 'Ston' with: '0.14';
			project: 'Glamour' with: '3.3.0';
			project: 'VirtualGPU' with:'0.1-baseline'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.422'. ]
! !

!ConfigurationOfKendrick methodsFor: 'as yet unclassified' stamp: 'SergeStinckwich 11/4/2015 17:09'!
version024: spec
	<version: '0.24' imports: #('0.9-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.24'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '11/4/2015 16:12'.
		spec 
			project: 'Moose' with: '5.1';
			project: 'SciSmalltalk' with: '0.25-baseline';
			project: 'Ston' with: '0.14';
			project: 'Glamour' with: '3.3.0';
			project: 'VirtualGPU' with: '0.1-baseline'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.451'. ]
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/15/2014 15:26'!
version02: spec
	<version: '0.2' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.2'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/15/2014 15:25'.
		spec project: 'Moose' with: '5.0-baseline'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.187'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/16/2014 16:22'!
version03: spec
	<version: '0.3' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.3'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/16/2014 14:34'.
		spec project: 'Moose' with: '5.0-baseline'.
		spec project: 'SciSmalltalk' with: '0.8'.
		spec 
			package: 'Kendrick' with: 'Kendrick-SergeStinckwich.187' ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/16/2014 17:01'!
version04: spec
	<version: '0.4' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.4'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/16/2014 17:01'.
		spec project: 'Moose' with: '5.0-baseline'.
		spec project: 'SciSmalltalk' with: '0.9'.
		spec 
			package: 'Kendrick' with: 'Kendrick-SergeStinckwich.187' ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 4/25/2014 00:24'!
version05: spec
	<version: '0.5' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.5'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '4/25/2014 00:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.9'.
		spec package: 'Kendrick' with: 'Kendrick-FabriceATREVI.189'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 6/18/2014 17:25'!
version06: spec
	<version: '0.6' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.6'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '6/17/2014 00:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.9'.
		spec package: 'Kendrick' with: 'Kendrick-ATREVIFabrice.196'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 6/18/2014 17:24'!
version07: spec
	<version: '0.7' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.7'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '6/18/2014 00:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.9'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.197'. ].
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 9/19/2014 13:17'!
version08: spec
	<version: '0.8' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.8'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '7/24/2014 16:33'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.12'.
		spec package: 'Kendrick' with: 'Kendrick-SergeStinckwich.197']
! !

!ConfigurationOfKendrick methodsFor: 'versions' stamp: 'SergeStinckwich 9/19/2014 13:17'!
version09: spec
	<version: '0.9' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.9'.
		spec author: 'SergeStinckwich'.
		spec timestamp: '9/19/2014 13:16'.
		spec 
			project: 'Moose' with: '5.0-baseline';
			project: 'SciSmalltalk' with: '0.14'.
		spec package: 'Kendrick' with: 'Kendrick-BuiThiMaiAnh.269']
! !
